@@ -1649,7 +1649,7 @@ ModuleExport size_t RegisterJPEGImage(void)
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->mime_type=ConstantString("image/jpeg");
-  entry->module=ConstantString("JPEG");
+  entry->magick_module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPEG");
 #if (JPEG_LIB_VERSION < 80) && !defined(LIBJPEG_TURBO_VERSION)
@@ -1666,7 +1666,7 @@ ModuleExport size_t RegisterJPEGImage(void)
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->mime_type=ConstantString("image/jpeg");
-  entry->module=ConstantString("JPEG");
+  entry->magick_module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPG");
 #if (JPEG_LIB_VERSION < 80) && !defined(LIBJPEG_TURBO_VERSION)
@@ -1682,7 +1682,7 @@ ModuleExport size_t RegisterJPEGImage(void)
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->mime_type=ConstantString("image/jpeg");
-  entry->module=ConstantString("JPEG");
+  entry->magick_module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPS");
 #if (JPEG_LIB_VERSION < 80) && !defined(LIBJPEG_TURBO_VERSION)
@@ -1698,7 +1698,7 @@ ModuleExport size_t RegisterJPEGImage(void)
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->mime_type=ConstantString("image/jpeg");
-  entry->module=ConstantString("JPEG");
+  entry->magick_module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PJPEG");
 #if (JPEG_LIB_VERSION < 80) && !defined(LIBJPEG_TURBO_VERSION)
@@ -1714,7 +1714,7 @@ ModuleExport size_t RegisterJPEGImage(void)
   if (*version != '\0')
     entry->version=ConstantString(version);
   entry->mime_type=ConstantString("image/jpeg");
-  entry->module=ConstantString("JPEG");
+  entry->magick_module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
@@ -2817,9 +2817,15 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   */
   value=GetImageProperty(image,"comment");
   if (value != (char *) NULL)
-    for (i=0; i < (ssize_t) strlen(value); i+=65533L)
-      jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) value+i,
-        (unsigned int) MagickMin((size_t) strlen(value+i),65533L));
+    {
+      size_t
+        length;
+
+      length=strlen(value);
+      for (i=0; i < (ssize_t) length; i+=65533L)
+        jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) value+i,
+          (unsigned int) MagickMin((size_t) strlen(value+i),65533L));
+    }
   if (image->profiles != (void *) NULL)
     WriteProfile(&jpeg_info,image);
   /*
