@@ -1459,7 +1459,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Photoshop resource format");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("8BIMTEXT");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1468,7 +1468,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Photoshop resource text format");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("8BIMWTEXT");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1477,7 +1477,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Photoshop resource wide text format");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("APP1");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1486,7 +1486,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Raw application information");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("APP1JPEG");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1495,7 +1495,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Raw JPEG binary data");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EXIF");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1504,7 +1504,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Exif digital camera binary data");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("XMP");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1513,7 +1513,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("Adobe XML metadata");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("ICM");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1522,7 +1522,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("ICC Color Profile");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("ICC");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1531,7 +1531,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("ICC Color Profile");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("IPTC");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1540,7 +1540,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("IPTC Newsphoto");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("IPTCTEXT");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1549,7 +1549,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("IPTC Newsphoto text format");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("IPTCWTEXT");
   entry->decoder=(DecodeImageHandler *) ReadMETAImage;
@@ -1558,7 +1558,7 @@ ModuleExport size_t RegisterMETAImage(void)
   entry->stealth=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->description=ConstantString("IPTC Newsphoto text format");
-  entry->module=ConstantString("META");
+  entry->magick_module=ConstantString("META");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
